@@ -182,7 +182,6 @@ Tellico::Data::EntryPtr ComicVineFetcher::fetchEntryHookData(Data::EntryPtr entr
     if(!pub.isEmpty()) {
       Data::EntryPtr e = coll->entries().front();
       if(e) {
-        myDebug() << pub;
         e->setField(QStringLiteral("publisher"), pub);
       }
     }
@@ -246,7 +245,7 @@ ComicVineFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const ComicVineFe
   l->addWidget(label, ++row, 0);
 
   m_apiKeyEdit = new QLineEdit(optionsWidget());
-  connect(m_apiKeyEdit, SIGNAL(textChanged(QString)), SLOT(slotSetModified()));
+  connect(m_apiKeyEdit, &QLineEdit::textChanged, this, &ConfigWidget::slotSetModified);
   l->addWidget(m_apiKeyEdit, row, 1);
   QString w = i18n("The default Tellico key may be used, but searching may fail due to reaching access limits.");
   label->setWhatsThis(w);
