@@ -97,8 +97,8 @@ private:
 
   bool m_started;
 
-  QHash<int, QUrl> m_matches;
-  QHash<int, Data::EntryPtr> m_entries;
+  QHash<uint, QUrl> m_matches;
+  QHash<uint, Data::EntryPtr> m_entries;
   QPointer<KIO::StoredTransferJob> m_job;
 };
 
