@@ -168,10 +168,10 @@ void Manager::startSearch(const QString& source_, Tellico::Fetch::FetchKey key_,
   foreach(Fetcher::Ptr fetcher, m_fetchers) {
     if(source_ == fetcher->source()) {
       ++m_count; // Fetcher::search() might emit done(), so increment before calling search()
-      connect(fetcher.data(), SIGNAL(signalResultFound(Tellico::Fetch::FetchResult*)),
-              SIGNAL(signalResultFound(Tellico::Fetch::FetchResult*)));
-      connect(fetcher.data(), SIGNAL(signalDone(Tellico::Fetch::Fetcher*)),
-              SLOT(slotFetcherDone(Tellico::Fetch::Fetcher*)));
+      connect(fetcher.data(), &Fetcher::signalResultFound,
+              this, &Manager::signalResultFound);
+      connect(fetcher.data(), &Fetcher::signalDone,
+              this, &Manager::slotFetcherDone);
       fetcher->startSearch(request);
       m_currentFetcherIndex = i;
       break;
@@ -189,10 +189,10 @@ void Manager::continueSearch() {
   Fetcher::Ptr fetcher = m_fetchers[m_currentFetcherIndex];
   if(fetcher && fetcher->hasMoreResults()) {
     ++m_count;
-    connect(fetcher.data(), SIGNAL(signalResultFound(Tellico::Fetch::FetchResult*)),
-            SIGNAL(signalResultFound(Tellico::Fetch::FetchResult*)));
-    connect(fetcher.data(), SIGNAL(signalDone(Tellico::Fetch::Fetcher*)),
-            SLOT(slotFetcherDone(Tellico::Fetch::Fetcher*)));
+    connect(fetcher.data(), &Fetcher::signalResultFound,
+            this, &Manager::signalResultFound);
+    connect(fetcher.data(), &Fetcher::signalDone,
+            this, &Manager::slotFetcherDone);
     fetcher->continueSearch();
   } else {
     emit signalDone();
@@ -305,6 +305,7 @@ Tellico::Fetch::FetcherVec Manager::defaultFetchers() {
 // comic books
   FETCHER_ADD(AnimeNfo);
   FETCHER_ADD(Bedetheque);
+  FETCHER_ADD(ComicVine);
 // bibliographic
   FETCHER_ADD(Arxiv);
   FETCHER_ADD(GoogleScholar);
@@ -341,8 +342,8 @@ Tellico::Fetch::FetcherVec Manager::defaultFetchers() {
   if(langs.contains(QStringLiteral("ru"))) {
     FETCHER_ADD(KinoPoisk);
   }
-  if(langs.contains(QStringLiteral("ru"))) {
-    FETCHER_ADD(KinoPoisk);
+  if(langs.contains(QStringLiteral("ua"))) {
+    FETCHER_ADD(KinoTeatr);
   }
   if(langs.contains(QStringLiteral("de"))) {
     FETCHER_ADD(Kino);
