@@ -127,8 +127,8 @@ void GoogleScholarFetcher::doSearch() {
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
-  connect(m_job, SIGNAL(result(KJob*)),
-          SLOT(slotComplete(KJob*)));
+  connect(m_job.data(), &KJob::result,
+          this, &GoogleScholarFetcher::slotComplete);
 }
 
 void GoogleScholarFetcher::stop() {
