@@ -97,8 +97,8 @@ void KinoFetcher::search() {
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
-  connect(m_job, SIGNAL(result(KJob*)),
-          SLOT(slotComplete(KJob*)));
+  connect(m_job.data(), &KJob::result,
+          this, &KinoFetcher::slotComplete);
 }
 
 void KinoFetcher::stop() {
@@ -155,8 +155,8 @@ void KinoFetcher::slotComplete(KJob*) {
     if(u.isEmpty()) {
       continue;
     }
-    if(u.startsWith(QStringLiteral("//"))) {
-      u.prepend(QStringLiteral("https:"));
+    if(u.startsWith(QLatin1String("//"))) {
+      u.prepend(QLatin1String("https:"));
     }
     Data::CollPtr coll(new Data::VideoCollection(true));
     Data::EntryPtr entry(new Data::Entry(coll));
@@ -240,7 +240,12 @@ void KinoFetcher::parseEntry(Data::EntryPtr entry, const QString& str_) {
     if(!actors.isEmpty()) {
       entry->setField(QStringLiteral("cast"), actors.join(FieldFormat::rowDelimiterString()));
     }
-    entry->setField(QStringLiteral("cover"), mapValue(objectMap, "image"));
+    // cover could be a relative link
+    QString coverLink = mapValue(objectMap, "image");
+    if(coverLink.startsWith(QLatin1String("//"))) {
+      coverLink.prepend(QLatin1String("https:"));
+    }
+    entry->setField(QStringLiteral("cover"), coverLink);
   }
 
   QRegularExpression tagRx(QStringLiteral("<.+?>"));
@@ -289,13 +294,13 @@ void KinoFetcher::parseEntry(Data::EntryPtr entry, const QString& str_) {
     QString c = certMatch.captured(1).remove(tagRx);
     if(c == QStringLiteral("ab 0")) {
       c = QStringLiteral("FSK 0 (DE)");
-    } else if(c == QStringLiteral("ab 6")) {
+    } else if(c == QLatin1String("ab 6")) {
       c = QStringLiteral("FSK 6 (DE)");
-    } else if(c == QStringLiteral("ab 12")) {
+    } else if(c == QLatin1String("ab 12")) {
       c = QStringLiteral("FSK 12 (DE)");
-    } else if(c == QStringLiteral("ab 16")) {
+    } else if(c == QLatin1String("ab 16")) {
       c = QStringLiteral("FSK 16 (DE)");
-    } else if(c == QStringLiteral("ab 18")) {
+    } else if(c == QLatin1String("ab 18")) {
       c = QStringLiteral("FSK 18 (DE)");
     }
     entry->setField(QStringLiteral("certification"), c);
