@@ -29,12 +29,12 @@ class RatingDelegate : public QStyledItemDelegate {
 Q_OBJECT
 
 public:
-  RatingDelegate(QObject* parent = 0);
+  RatingDelegate(QObject* parent = nullptr);
 
   void setMaxRating(uint rating_) { m_maxRating = rating_; }
-  void paint(QPainter* painter, const QStyleOptionViewItem& option,const QModelIndex& index) const;
+  void paint(QPainter* painter, const QStyleOptionViewItem& option,const QModelIndex& index) const Q_DECL_OVERRIDE;
 
-  QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
+  QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const Q_DECL_OVERRIDE;
 
 private:
   uint m_maxRating;
