@@ -30,8 +30,7 @@
 
 #include <QIcon>
 #include <QAbstractItemModel>
-#include <QHash>
-#include <QCache>
+#include <QMultiHash>
 
 namespace Tellico {
 
@@ -76,8 +75,7 @@ private Q_SLOTS:
 private:
   Data::EntryPtr entry(const QModelIndex& index) const;
   Data::FieldPtr field(const QModelIndex& index) const;
-  const QIcon& defaultIcon(Data::CollPtr coll) const;
-  QString imageField(Data::CollPtr coll) const;
+  QVariant requestImage(Data::EntryPtr entry, const QString& id) const;
 
   Data::EntryList m_entries;
   Data::FieldList m_fields;
@@ -85,9 +83,6 @@ private:
   QHash<int, int> m_saveStates;
   bool m_imagesAreAvailable;
 
-  mutable QHash<int, QIcon*> m_defaultIcons;
-  mutable QHash<long, QString> m_imageFields;
-  mutable QCache<QString, QIcon> m_iconCache;
   // maps ids of requested images into entries
   mutable QMultiHash<QString, Data::EntryPtr> m_requestedImages;
 };
