@@ -25,14 +25,14 @@
 #undef QT_NO_CAST_FROM_ASCII
 
 #include "openlibraryfetchertest.h"
-#include "openlibraryfetchertest.moc"
-#include "qtest_kde.h"
 
 #include "../fetch/openlibraryfetcher.h"
 #include "../entry.h"
 #include "../images/imagefactory.h"
 
-QTEST_KDEMAIN( OpenLibraryFetcherTest, GUI )
+#include <QTest>
+
+QTEST_GUILESS_MAIN( OpenLibraryFetcherTest )
 
 OpenLibraryFetcherTest::OpenLibraryFetcherTest() : AbstractFetcherTest() {
 }
@@ -43,7 +43,7 @@ void OpenLibraryFetcherTest::initTestCase() {
 
 void OpenLibraryFetcherTest::testIsbn() {
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Book, Tellico::Fetch::ISBN,
-                                       QLatin1String("0789312239"));
+                                       QStringLiteral("0789312239"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::OpenLibraryFetcher(this));
 
   Tellico::Data::EntryList results = DO_FETCH(fetcher, request);
@@ -51,22 +51,22 @@ void OpenLibraryFetcherTest::testIsbn() {
   QCOMPARE(results.size(), 1);
 
   Tellico::Data::EntryPtr entry = results.at(0);
-  QCOMPARE(entry->field(QLatin1String("title")), QLatin1String("This is Venice"));
-  QCOMPARE(entry->field(QLatin1String("author")), QLatin1String("M. Sasek"));
-  QCOMPARE(entry->field(QLatin1String("isbn")), QLatin1String("0-7893-1223-9"));
-  QCOMPARE(entry->field(QLatin1String("lccn")), QLatin1String("2004110229"));
-  QCOMPARE(entry->field(QLatin1String("pub_year")), QLatin1String("2005"));
-  QCOMPARE(entry->field(QLatin1String("genre")), QLatin1String("Juvenile literature."));
-  QCOMPARE(entry->field(QLatin1String("keyword")), QLatin1String("Venice (Italy) -- Description and travel -- Juvenile literature"));
-  QCOMPARE(entry->field(QLatin1String("publisher")), QLatin1String("Universe"));
-  QCOMPARE(entry->field(QLatin1String("language")), QLatin1String("English"));
-  QCOMPARE(entry->field(QLatin1String("pages")), QLatin1String("56"));
-  QVERIFY(!entry->field(QLatin1String("comments")).isEmpty());
+  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("This is Venice"));
+  QCOMPARE(entry->field(QStringLiteral("author")), QStringLiteral("M. Sasek"));
+  QCOMPARE(entry->field(QStringLiteral("isbn")), QStringLiteral("0-7893-1223-9"));
+  QCOMPARE(entry->field(QStringLiteral("lccn")), QStringLiteral("2004110229"));
+  QCOMPARE(entry->field(QStringLiteral("pub_year")), QStringLiteral("2005"));
+  QCOMPARE(entry->field(QStringLiteral("genre")), QStringLiteral("Juvenile literature."));
+  QCOMPARE(entry->field(QStringLiteral("keyword")), QStringLiteral("Venice (Italy) -- Description and travel -- Juvenile literature"));
+  QCOMPARE(entry->field(QStringLiteral("publisher")), QStringLiteral("Universe"));
+  QCOMPARE(entry->field(QStringLiteral("language")), QStringLiteral("English"));
+  QCOMPARE(entry->field(QStringLiteral("pages")), QStringLiteral("56"));
+  QVERIFY(!entry->field(QStringLiteral("comments")).isEmpty());
 }
 
 void OpenLibraryFetcherTest::testIsbn13() {
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Book, Tellico::Fetch::ISBN,
-                                       QLatin1String("9780596004361"));
+                                       QStringLiteral("9780596004361"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::OpenLibraryFetcher(this));
 
   Tellico::Data::EntryList results = DO_FETCH(fetcher, request);
@@ -74,12 +74,12 @@ void OpenLibraryFetcherTest::testIsbn13() {
   QCOMPARE(results.size(), 1);
 
   Tellico::Data::EntryPtr entry = results.at(0);
-  QCOMPARE(entry->field(QLatin1String("title")), QLatin1String("C Pocket Reference"));
+  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("C Pocket Reference"));
 }
 
 void OpenLibraryFetcherTest::testMultipleIsbn() {
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Book, Tellico::Fetch::ISBN,
-                                       QLatin1String("0789312239; 9780596000486"));
+                                       QStringLiteral("0789312239; 9780596000486"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::OpenLibraryFetcher(this));
 
   Tellico::Data::EntryList results = DO_FETCH(fetcher, request);
