@@ -45,33 +45,33 @@ void RISImporter::initTagMap() {
   if(!s_tagMap) {
     s_tagMap = new QHash<QString, QString>();
     // BT is special and is handled separately
-    s_tagMap->insert(QLatin1String("TY"), QLatin1String("entry-type"));
-    s_tagMap->insert(QLatin1String("ID"), QLatin1String("bibtex-key"));
-    s_tagMap->insert(QLatin1String("T1"), QLatin1String("title"));
-    s_tagMap->insert(QLatin1String("TI"), QLatin1String("title"));
-    s_tagMap->insert(QLatin1String("T2"), QLatin1String("booktitle"));
-    s_tagMap->insert(QLatin1String("A1"), QLatin1String("author"));
-    s_tagMap->insert(QLatin1String("AU"), QLatin1String("author"));
-    s_tagMap->insert(QLatin1String("ED"), QLatin1String("editor"));
-    s_tagMap->insert(QLatin1String("YR"), QLatin1String("year"));
-    s_tagMap->insert(QLatin1String("PY"), QLatin1String("year"));
-    s_tagMap->insert(QLatin1String("N1"), QLatin1String("note"));
-    s_tagMap->insert(QLatin1String("AB"), QLatin1String("abstract")); // should be note?
-    s_tagMap->insert(QLatin1String("N2"), QLatin1String("abstract"));
-    s_tagMap->insert(QLatin1String("KW"), QLatin1String("keyword"));
-    s_tagMap->insert(QLatin1String("JF"), QLatin1String("journal"));
-    s_tagMap->insert(QLatin1String("JO"), QLatin1String("journal"));
-    s_tagMap->insert(QLatin1String("JA"), QLatin1String("journal"));
-    s_tagMap->insert(QLatin1String("VL"), QLatin1String("volume"));
-    s_tagMap->insert(QLatin1String("IS"), QLatin1String("number"));
-    s_tagMap->insert(QLatin1String("PB"), QLatin1String("publisher"));
-    s_tagMap->insert(QLatin1String("SN"), QLatin1String("isbn"));
-    s_tagMap->insert(QLatin1String("AD"), QLatin1String("address"));
-    s_tagMap->insert(QLatin1String("CY"), QLatin1String("address"));
-    s_tagMap->insert(QLatin1String("UR"), QLatin1String("url"));
-    s_tagMap->insert(QLatin1String("L1"), QLatin1String("pdf"));
-    s_tagMap->insert(QLatin1String("T3"), QLatin1String("series"));
-    s_tagMap->insert(QLatin1String("EP"), QLatin1String("pages"));
+    s_tagMap->insert(QStringLiteral("TY"), QStringLiteral("entry-type"));
+    s_tagMap->insert(QStringLiteral("ID"), QStringLiteral("bibtex-key"));
+    s_tagMap->insert(QStringLiteral("T1"), QStringLiteral("title"));
+    s_tagMap->insert(QStringLiteral("TI"), QStringLiteral("title"));
+    s_tagMap->insert(QStringLiteral("T2"), QStringLiteral("booktitle"));
+    s_tagMap->insert(QStringLiteral("A1"), QStringLiteral("author"));
+    s_tagMap->insert(QStringLiteral("AU"), QStringLiteral("author"));
+    s_tagMap->insert(QStringLiteral("ED"), QStringLiteral("editor"));
+    s_tagMap->insert(QStringLiteral("YR"), QStringLiteral("year"));
+    s_tagMap->insert(QStringLiteral("PY"), QStringLiteral("year"));
+    s_tagMap->insert(QStringLiteral("N1"), QStringLiteral("note"));
+    s_tagMap->insert(QStringLiteral("AB"), QStringLiteral("abstract")); // should be note?
+    s_tagMap->insert(QStringLiteral("N2"), QStringLiteral("abstract"));
+    s_tagMap->insert(QStringLiteral("KW"), QStringLiteral("keyword"));
+    s_tagMap->insert(QStringLiteral("JF"), QStringLiteral("journal"));
+    s_tagMap->insert(QStringLiteral("JO"), QStringLiteral("journal"));
+    s_tagMap->insert(QStringLiteral("JA"), QStringLiteral("journal"));
+    s_tagMap->insert(QStringLiteral("VL"), QStringLiteral("volume"));
+    s_tagMap->insert(QStringLiteral("IS"), QStringLiteral("number"));
+    s_tagMap->insert(QStringLiteral("PB"), QStringLiteral("publisher"));
+    s_tagMap->insert(QStringLiteral("SN"), QStringLiteral("isbn"));
+    s_tagMap->insert(QStringLiteral("AD"), QStringLiteral("address"));
+    s_tagMap->insert(QStringLiteral("CY"), QStringLiteral("address"));
+    s_tagMap->insert(QStringLiteral("UR"), QStringLiteral("url"));
+    s_tagMap->insert(QStringLiteral("L1"), QStringLiteral("pdf"));
+    s_tagMap->insert(QStringLiteral("T3"), QStringLiteral("series"));
+    s_tagMap->insert(QStringLiteral("EP"), QStringLiteral("pages"));
   }
 }
 
@@ -80,41 +80,41 @@ void RISImporter::initTypeMap() {
   if(!s_typeMap) {
     s_typeMap = new QHash<QString, QString>();
     // leave capitalized, except for bibtex types
-    s_typeMap->insert(QLatin1String("ABST"),   QLatin1String("Abstract"));
-    s_typeMap->insert(QLatin1String("ADVS"),   QLatin1String("Audiovisual material"));
-    s_typeMap->insert(QLatin1String("ART"),    QLatin1String("Art Work"));
-    s_typeMap->insert(QLatin1String("BILL"),   QLatin1String("Bill/Resolution"));
-    s_typeMap->insert(QLatin1String("BOOK"),   QLatin1String("book")); // bibtex
-    s_typeMap->insert(QLatin1String("CASE"),   QLatin1String("Case"));
-    s_typeMap->insert(QLatin1String("CHAP"),   QLatin1String("inbook")); // == "inbook" ?
-    s_typeMap->insert(QLatin1String("COMP"),   QLatin1String("Computer program"));
-    s_typeMap->insert(QLatin1String("CONF"),   QLatin1String("inproceedings")); // == "conference" ?
-    s_typeMap->insert(QLatin1String("CTLG"),   QLatin1String("Catalog"));
-    s_typeMap->insert(QLatin1String("DATA"),   QLatin1String("Data file"));
-    s_typeMap->insert(QLatin1String("ELEC"),   QLatin1String("Electronic Citation"));
-    s_typeMap->insert(QLatin1String("GEN"),    QLatin1String("Generic"));
-    s_typeMap->insert(QLatin1String("HEAR"),   QLatin1String("Hearing"));
-    s_typeMap->insert(QLatin1String("ICOMM"),  QLatin1String("Internet Communication"));
-    s_typeMap->insert(QLatin1String("INPR"),   QLatin1String("In Press"));
-    s_typeMap->insert(QLatin1String("JFULL"),  QLatin1String("Journal (full)")); // = "periodical" ?
-    s_typeMap->insert(QLatin1String("JOUR"),   QLatin1String("article")); // "Journal"
-    s_typeMap->insert(QLatin1String("MAP"),    QLatin1String("Map"));
-    s_typeMap->insert(QLatin1String("MGZN"),   QLatin1String("article")); // bibtex
-    s_typeMap->insert(QLatin1String("MPCT"),   QLatin1String("Motion picture"));
-    s_typeMap->insert(QLatin1String("MUSIC"),  QLatin1String("Music score"));
-    s_typeMap->insert(QLatin1String("NEWS"),   QLatin1String("Newspaper"));
-    s_typeMap->insert(QLatin1String("PAMP"),   QLatin1String("Pamphlet")); // = "booklet" ?
-    s_typeMap->insert(QLatin1String("PAT"),    QLatin1String("Patent"));
-    s_typeMap->insert(QLatin1String("PCOMM"),  QLatin1String("Personal communication"));
-    s_typeMap->insert(QLatin1String("RPRT"),   QLatin1String("Report")); // = "techreport" ?
-    s_typeMap->insert(QLatin1String("SER"),    QLatin1String("Serial (BookMonograph)"));
-    s_typeMap->insert(QLatin1String("SLIDE"),  QLatin1String("Slide"));
-    s_typeMap->insert(QLatin1String("SOUND"),  QLatin1String("Sound recording"));
-    s_typeMap->insert(QLatin1String("STAT"),   QLatin1String("Statute"));
-    s_typeMap->insert(QLatin1String("THES"),   QLatin1String("phdthesis")); // "mastersthesis" ?
-    s_typeMap->insert(QLatin1String("UNBILL"), QLatin1String("Unenacted bill/resolution"));
-    s_typeMap->insert(QLatin1String("UNPB"),   QLatin1String("unpublished")); // bibtex
-    s_typeMap->insert(QLatin1String("VIDEO"),  QLatin1String("Video recording"));
+    s_typeMap->insert(QStringLiteral("ABST"),   QStringLiteral("Abstract"));
+    s_typeMap->insert(QStringLiteral("ADVS"),   QStringLiteral("Audiovisual material"));
+    s_typeMap->insert(QStringLiteral("ART"),    QStringLiteral("Art Work"));
+    s_typeMap->insert(QStringLiteral("BILL"),   QStringLiteral("Bill/Resolution"));
+    s_typeMap->insert(QStringLiteral("BOOK"),   QStringLiteral("book")); // bibtex
+    s_typeMap->insert(QStringLiteral("CASE"),   QStringLiteral("Case"));
+    s_typeMap->insert(QStringLiteral("CHAP"),   QStringLiteral("inbook")); // == "inbook" ?
+    s_typeMap->insert(QStringLiteral("COMP"),   QStringLiteral("Computer program"));
+    s_typeMap->insert(QStringLiteral("CONF"),   QStringLiteral("inproceedings")); // == "conference" ?
+    s_typeMap->insert(QStringLiteral("CTLG"),   QStringLiteral("Catalog"));
+    s_typeMap->insert(QStringLiteral("DATA"),   QStringLiteral("Data file"));
+    s_typeMap->insert(QStringLiteral("ELEC"),   QStringLiteral("Electronic Citation"));
+    s_typeMap->insert(QStringLiteral("GEN"),    QStringLiteral("Generic"));
+    s_typeMap->insert(QStringLiteral("HEAR"),   QStringLiteral("Hearing"));
+    s_typeMap->insert(QStringLiteral("ICOMM"),  QStringLiteral("Internet Communication"));
+    s_typeMap->insert(QStringLiteral("INPR"),   QStringLiteral("In Press"));
+    s_typeMap->insert(QStringLiteral("JFULL"),  QStringLiteral("Journal (full)")); // = "periodical" ?
+    s_typeMap->insert(QStringLiteral("JOUR"),   QStringLiteral("article")); // "Journal"
+    s_typeMap->insert(QStringLiteral("MAP"),    QStringLiteral("Map"));
+    s_typeMap->insert(QStringLiteral("MGZN"),   QStringLiteral("article")); // bibtex
+    s_typeMap->insert(QStringLiteral("MPCT"),   QStringLiteral("Motion picture"));
+    s_typeMap->insert(QStringLiteral("MUSIC"),  QStringLiteral("Music score"));
+    s_typeMap->insert(QStringLiteral("NEWS"),   QStringLiteral("Newspaper"));
+    s_typeMap->insert(QStringLiteral("PAMP"),   QStringLiteral("Pamphlet")); // = "booklet" ?
+    s_typeMap->insert(QStringLiteral("PAT"),    QStringLiteral("Patent"));
+    s_typeMap->insert(QStringLiteral("PCOMM"),  QStringLiteral("Personal communication"));
+    s_typeMap->insert(QStringLiteral("RPRT"),   QStringLiteral("Report")); // = "techreport" ?
+    s_typeMap->insert(QStringLiteral("SER"),    QStringLiteral("Serial (BookMonograph)"));
+    s_typeMap->insert(QStringLiteral("SLIDE"),  QStringLiteral("Slide"));
+    s_typeMap->insert(QStringLiteral("SOUND"),  QStringLiteral("Sound recording"));
+    s_typeMap->insert(QStringLiteral("STAT"),   QStringLiteral("Statute"));
+    s_typeMap->insert(QStringLiteral("THES"),   QStringLiteral("phdthesis")); // "mastersthesis" ?
+    s_typeMap->insert(QStringLiteral("UNBILL"), QStringLiteral("Unenacted bill/resolution"));
+    s_typeMap->insert(QStringLiteral("UNPB"),   QStringLiteral("unpublished")); // bibtex
+    s_typeMap->insert(QStringLiteral("VIDEO"),  QStringLiteral("Video recording"));
   }
 }
 
@@ -147,7 +147,7 @@ Tellico::Data::CollPtr RISImporter::collection() {
   if(currColl) {
     foreach(Data::FieldPtr field, currColl->fields()) {
       // continue if property is empty
-      QString ris = field->property(QLatin1String("ris"));
+      QString ris = field->property(QStringLiteral("ris"));
       if(ris.isEmpty()) {
         continue;
       }
@@ -157,7 +157,7 @@ Tellico::Data::CollPtr RISImporter::collection() {
         f = new Data::Field(*field);
         m_coll->addField(f);
       }
-      f->setProperty(QLatin1String("ris"), ris);
+      f->setProperty(QStringLiteral("ris"), ris);
       risFields.insert(ris, f);
     }
   }
@@ -252,7 +252,7 @@ void RISImporter::readText(const QString& text_, int n, const QHash<QString, Tel
           ep = QString::number(startPage + endPage);
         }
         value = sp + QLatin1Char('-') + ep;
-        tag = QLatin1String("EP");
+        tag = QStringLiteral("EP");
         sp.clear();
         ep.clear();
       } else {
@@ -286,10 +286,10 @@ void RISImporter::readText(const QString& text_, int n, const QHash<QString, Tel
       // special case for BT
       // primary title for books, secondary for everything else
       if(tag == QLatin1String("BT")) {
-        if(entry->field(QLatin1String("entry-type")) == QLatin1String("book")) {
-          f = m_coll->fieldByName(QLatin1String("title"));
+        if(entry->field(QStringLiteral("entry-type")) == QLatin1String("book")) {
+          f = m_coll->fieldByName(QStringLiteral("title"));
         } else {
-          f = m_coll->fieldByName(QLatin1String("booktitle"));
+          f = m_coll->fieldByName(QStringLiteral("booktitle"));
         }
       } else {
         f = fieldByTag(tag);
@@ -325,15 +325,15 @@ Tellico::Data::FieldPtr RISImporter::fieldByTag(const QString& tag_) {
   if(!fieldTag.isEmpty()) {
     f = m_coll->fieldByName(fieldTag);
     if(f) {
-      f->setProperty(QLatin1String("ris"), tag_);
+      f->setProperty(QStringLiteral("ris"), tag_);
       return f;
     }
   }
 
   // add non-default fields if not already there
   if(tag_== QLatin1String("L1")) {
-    f = new Data::Field(QLatin1String("pdf"), i18n("PDF"), Data::Field::URL);
-    f->setProperty(QLatin1String("ris"), QLatin1String("L1"));
+    f = new Data::Field(QStringLiteral("pdf"), i18n("PDF"), Data::Field::URL);
+    f->setProperty(QStringLiteral("ris"), QStringLiteral("L1"));
     f->setCategory(i18n("Miscellaneous"));
   }
   m_coll->addField(f);
