@@ -28,7 +28,7 @@
 #include <libxml/parser.h> // has to be before valid.h
 #include <libxml/valid.h>
 
-#include <QRegExp>
+#include <QRegularExpression>
 
 const QString Tellico::XML::nsXSL = QStringLiteral("http://www.w3.org/1999/XSL/Transform");
 const QString Tellico::XML::nsBibtexml = QStringLiteral("http://bibtexml.sf.net/");
@@ -58,7 +58,7 @@ const QString Tellico::XML::dtdBibtexml = QStringLiteral("bibtexml.dtd");
  *
  * VERSION 10 added the game board collection.
  *
- * VERSION 11 remove ReadOnly and Dependent fields, and added apprioriate FieldFlags. An ID field was added by default.
+ * VERSION 11 remove ReadOnly and Dependent fields, and added appropriate FieldFlags. An ID field was added by default.
  *
  * VERSION 12 added new filter rules: before and after, less than and greater than. But only use v12 when needed
  */
@@ -83,9 +83,10 @@ bool Tellico::XML::validXMLElementName(const QString& name_) {
 }
 
 QString Tellico::XML::elementName(const QString& name_) {
+  static const QRegularExpression whitespace(QStringLiteral("\\s+"));
   QString name = name_;
   // change white space to dashes
-  name.replace(QRegExp(QLatin1String("\\s+")), QStringLiteral("-"));
+  name.replace(whitespace, QStringLiteral("-"));
   // first cut, if it passes, we're done
   if(XML::validXMLElementName(name)) {
     return name;
