@@ -65,6 +65,10 @@ public:
   /**
    */
   virtual Data::CollPtr collection() Q_DECL_OVERRIDE;
+  /**
+   * The TellicoImporter can import any type known to Tellico. Obviously.
+   */
+  virtual bool canImport(int type) const Q_DECL_OVERRIDE { Q_UNUSED(type); return true; }
   Format format() const { return m_format; }
 
   bool hasImages() const;
@@ -76,7 +80,7 @@ public:
   static bool loadAllImages(const QUrl& url);
 
 public Q_SLOTS:
-  void slotCancel();
+  void slotCancel() Q_DECL_OVERRIDE;
 
 private:
   void loadXMLData(const QByteArray& data, bool loadImages);
